@@ -21,8 +21,8 @@ import cvdast.CloudvectorDAST
 import shutil
 import sys
 
-from runconfig import inspecdir 
-import runconfig
+from cvdastwrapper.runconfig import inspecdir 
+from cvdastwrapper import runconfig
 
 def fuzzspecs(specdir = inspecdir):
     
